multivalent.MultivalentClient

|  | ## Cheshire3 Object Model: Class MultivalentClient

Module multivalent :: Class MultivalentClient

## Class MultivalentClient
source code

Instance Methods

__init__(self)
connect(self, host, port)
disconnect(self)
mvProtocol(self, data, attrs)

Class Variables

sock |
connectedToServer |

Method Details

### __init__(self) (Constructor) | source code

### connect(self, host, port) | source code

### disconnect(self) | source code

### mvProtocol(self, data, attrs) | source code

Class Variable Details

    ### sock Value:
        None

    ### connectedToServer Value:
        False